@@ -102,6 +102,8 @@ $cacti_version_codes = array(
 	'1.1.26' => '0101',
 	'1.1.27' => '0101',
 	'1.1.28' => '0101',
+	'1.1.29' => '0101',
+	'1.1.30' => '0101',
 );
 
 $messages = array(
@@ -132,6 +134,9 @@ $messages = array(
 	9  => array(
 		'message' => __('The Cacti log file must have the extension \'.log\''),
 		'type' => 'error'),
+	11  => array(
+		'message' => __('Data Source does not exist.'),
+		'type' => 'error'),
 	12 => array(
 		'message' => __('Username already in use.'),
 		'type' => 'error'),
@@ -219,6 +224,9 @@ $messages = array(
 	'clog_missing' => array(
 		'message' => __('Error: Unable to clear log, file does not exist'),
 		'type' => 'error'),
+	'csrf_timeout' => array(
+		'message' => '<i>' . __('CSRF Timeout, refreshing page.') . '</i>',
+		'type' => 'error'),
 	'mg_mailtime_invalid' => array(
 		'message' => __('Invalid Timestamp. Select timestamp in the future.'),
 		'type'    => 'error'),
