@@ -13,7 +13,7 @@
  | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the           |
  | GNU General Public License for more details.                            |
  +-------------------------------------------------------------------------+
- | Cacti: The Complete RRDTool-based Graphing Solution                     |
+ | Cacti: The Complete RRDtool-based Graphing Solution                     |
  +-------------------------------------------------------------------------+
  | This code is designed, written, and maintained by the Cacti Group. See  |
  | about.php and/or the AUTHORS file for specific developer information.   |
@@ -123,8 +123,15 @@ $fields_profile_rra_edit = array(
 		'default' => '600'
 		),
 	'timespan' => array(
+		'method' => 'drop_array',
+		'friendly_name' => __('Default Timespan'),
+		'description' => __('When viewing a Graph based upon the RRA in question, the default Timespan to show for that Graph.'),
+		'value' => '|arg1:timespan|',
+		'array' => $timespans
+		),
+	'retention' => array(
 		'method' => 'other',
-		'friendly_name' => __('Effective Retention'),
+		'friendly_name' => __('Data Retention'),
 		'description' => __('Based upon the Aggregation Level, the Rows, and the Polling Interval the amount of data that will be retained in the RRA'),
 		'value' => ''
 		),
@@ -358,6 +365,16 @@ $fields_data_template_template_edit = array(
 	);
 
 /* file: (data_sources.php|data_templates.php), action: (ds|template)_edit */
+
+if (db_table_exists('data_source_profiles')) {
+	$def_profile = db_fetch_cell('SELECT id 
+		FROM data_source_profiles 
+		ORDER BY `default` 
+		DESC LIMIT 1');
+} else {
+	$def_profile = '1';
+}
+
 $struct_data_source = array(
 	'name' => array(
 		'friendly_name' => __('Name'),
@@ -390,8 +407,8 @@ $struct_data_source = array(
 		'friendly_name' => __('Data Source Profile'),
 		'method' => 'drop_sql',
 		'description' => __('Select the Data Source Profile.  The Data Source Profile controls polling interval, the data aggregation, and retention policy for the resulting Data Sources.'),
-		'sql' => 'SELECT id, name FROM data_source_profiles ORDER BY name',
-		'none_value' => __('External'),
+		'sql' => 'SELECT "0" AS id, "' . __('External') . '" AS name UNION SELECT id, name FROM data_source_profiles ORDER BY name',
+		'default' => $def_profile,
 		'flags' => ''
 		),
 	'rrd_step' => array(
@@ -1551,7 +1568,7 @@ $fields_template_import = array(
 		'method' => 'file'
 		),
 	'import_text' => array(
-		'method' => 'textarea',
+		'method' => 'hidden',
 		'friendly_name' => __('Import Template from Text'),
 		'description' => __('If you have the XML file containing template data as text, you can paste it into this box to import it.'),
 		'value' => '',
