@@ -14,7 +14,7 @@
  | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the           |
  | GNU General Public License for more details.                            |
  +-------------------------------------------------------------------------+
- | Cacti: The Complete RRDTool-based Graphing Solution                     |
+ | Cacti: The Complete RRDtool-based Graphing Solution                     |
  +-------------------------------------------------------------------------+
  | This code is designed, written, and maintained by the Cacti Group. See  |
  | about.php and/or the AUTHORS file for specific developer information.   |
@@ -802,7 +802,7 @@ function format_snmp_string($string, $snmp_oid_included, $value_output_format =
 	$string = trim($string);
 
 	/* convert hex strings to numeric values */
-	if (is_hex_string($string) && $value_output_format == SNMP_VALUE_NUMERIC) {
+	if (is_hex_string($string) && $value_output_format == SNMP_STRING_OUTPUT_GUESS) {
 		$output = '';
 		$parts  = explode(' ', $string);
 
